import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DealsPageCmsRepository } from "./deals-page-cms.repository";
import { UpdateDealsPageCmsDto } from "./dto/update-deals-page-cms.dto";
import { DealsPageCms } from "./entities/deals-page-cms.entity";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Injectable()
export class DealsPageCmsService {
    constructor(
      @InjectRepository(DealsPageCmsRepository)
      private readonly repository: DealsPageCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateDealsPageCmsDto,
      files: {
          bannerDesktopImage: UploadedMulterFileI,
          bannerMobileImage: UploadedMulterFileI
      }
    ): Promise<DealsPageCms | Error> {
        if (files && files.bannerDesktopImage) {
            const bannerDesktopImage: any = await this.doSpaceService.uploadFile(files.bannerDesktopImage[0], "DealsPageCMS/");
            dto.bannerDesktopImage = bannerDesktopImage;
        }

        if (files && files.bannerMobileImage) {
            const bannerMobileImage: any = await this.doSpaceService.uploadFile(files.bannerMobileImage[0], "DealsPageCMS/");
            dto.bannerMobileImage = bannerMobileImage;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<DealsPageCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}