import { HttpException, HttpStatus, Injectable, NotFoundException } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { NewDropBannerCmsRepository } from "./new-drop-banner-cms.repository";
import { UpdateNewDropBannerCmsDto } from "./dto/update-new-drop-banner-cms.dto";
import { NewDropBannerCms } from "./entities/new-drop-banner-cms.entity";

@Injectable()
export class NewDropBannerCmsService {
    constructor(
      @InjectRepository(NewDropBannerCmsRepository)
      private readonly repository: NewDropBannerCmsRepository
    ) {
    }

    async updateOrCreateData(
      dto: UpdateNewDropBannerCmsDto
    ): Promise<NewDropBannerCms | Error> {
        const isExists = await this.repository.find({ isDeleted: false });
        // if (dto.isDefault) {
        //     // Retrieve all entities
        //     const entities = await this.repository.find();

        //     // Update the isDefault property for each entity
        //     for (const entity of entities) {
        //         const updateData = await this.repository.update(entity.id, { isDefault: false });
        //     }
        // }
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new NotFoundException(Constants.NOT_FOUND);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<NewDropBannerCms[] | Error> {
        const data = await this.repository.find({
            // stateCode: stateCode,
            isDeleted: false
        });
        if (!data) {
            throw new NotFoundException(Constants.NOT_FOUND);
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}