import { EntityRepository, Repository } from "typeorm";
import { NewsletterPopupCmsEntity } from "./entities/newsletter-popup-cms.entity";
import { UpdateNewsletterPopupCmsDto } from "./dto/update-newsletter-popup-cms.dto";

@EntityRepository(NewsletterPopupCmsEntity)
export class NewsletterPopupCmsRepository extends Repository<NewsletterPopupCmsEntity> {

    async createEntity(dto: UpdateNewsletterPopupCmsDto): Promise<NewsletterPopupCmsEntity | Error> {
        try {
            const entity = this.create({
                stateCode: dto.stateCode,
                stateName: dto.stateName,
                image: dto.image,
                heading: dto.heading,
                title: dto.title,
                subTitle: dto.subTitle,
                inputText: dto.inputText,
                placeholderText: dto.placeholderText,
                topButtonText: dto.topButtonText,
                bottomButtonText: dto.bottomButtonText,
                time: dto.time,
                expireTime: dto.expireTime,
                pages: dto.pages,
                isDefault: dto.isDefault
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateNewsletterPopupCmsDto, id: string): Promise<NewsletterPopupCmsEntity | Error> {
        try {
            await this.update(id, {
                stateCode: dto.stateCode,
                stateName: dto.stateName,
                image: dto.image,
                heading: dto.heading,
                title: dto.title,
                subTitle: dto.subTitle,
                inputText: dto.inputText,
                placeholderText: dto.placeholderText,
                topButtonText: dto.topButtonText,
                bottomButtonText: dto.bottomButtonText,
                time: dto.time,
                expireTime: dto.expireTime,
                pages: dto.pages,
                isDefault: dto.isDefault
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<NewsletterPopupCmsEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}