import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { productDetailsPageMetaDto } from "./dto/product-details-page-meta.dto";
import { productDetailsPageMeta } from "./entities/product-details-page-meta.entity";
import { productDetailsPageMetaRepository } from "./product-details-page-meta.repository";

@Injectable()
export class productDetailsPageMetaService {
    constructor(
      @InjectRepository(productDetailsPageMetaRepository)
      private readonly repository: productDetailsPageMetaRepository
    ) {
    }

    async updateOrCreateData(dto: productDetailsPageMetaDto): Promise<productDetailsPageMeta | Error> {
        const isExists = await this.repository.find();
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.GENERIC_ERROR,
                  HttpStatus.FORBIDDEN
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.FORBIDDEN
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
        }
    }

    async findAll(): Promise<productDetailsPageMeta[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
