import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../../SpacesModule/SpacesService";
import { UpdateShopPageBannerCmsDto } from "./dto/update-shop-page-section-seven-cms.dto";
import { ShopPageBannerCmsService } from "./shop-page-banner-cms.service";

@Controller({ path: "shop-page-banner-cms", version: Constants.API_VERSION_1 })

export class ShopPageBannerCmsController {
    constructor(private readonly service: ShopPageBannerCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateShopPageBannerCmsDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI,
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
