import { EntityRepository, getConnection, Repository } from "typeorm";
import { UpdateBillingAddressDto } from "./dto/update-billing-address.dto";
import { BillingAddress } from "./entities/billing-address.entity";

@EntityRepository(BillingAddress)
export class BillingAddressRepository extends Repository<BillingAddress> {
    async createEntity(dto: any): Promise<BillingAddress | Error> {
        try {
            const entity = this.create({
                name: dto.name,
                phone: dto.phone,
                email: dto.email,
                city: dto.city,
                postCode: dto.postCode,
                stateCode: dto.stateCode,
                country: dto.country,
                countryCode: dto.countryCode,
                addressOne: dto.addressOne,
                addressTwo: dto.addressTwo,
                userId: dto.userId
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<BillingAddress | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateBillingAddressDto): Promise<BillingAddress | Error> {
        try {
            await this.update(id, {
                name: dto.name,
                phone: dto.phone,
                email: dto.email,
                city: dto.city,
                postCode: dto.postCode,
                stateCode: dto.stateCode,
                country: dto.country,
                countryCode: dto.countryCode,
                addressOne: dto.addressOne,
                addressTwo: dto.addressTwo,
                userId: dto.userId
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<BillingAddress[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(BillingAddress)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async findByUserId(id: string): Promise<BillingAddress | Error> {
        try {
            return await this.findOne({
                where: { userId: id, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }
}