import { Body, Controller, Delete, Get, Param, Patch, Post, Req, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { ShippingAddressService } from "./shipping-address.service";
import { UpdateShippingAddressDto } from "./dto/update-shipping-address.dto";
import { AuthGuard } from "src/core/guards/auth.guard";

@Controller({ path: "shipping-address", version: Constants.API_VERSION_1 })

export class ShippingAddressController {
    constructor(private readonly service: ShippingAddressService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    create(
      @Body() dto: UpdateShippingAddressDto,
      @Req() request: any
    ) {
        return this.service.create(dto, request);
    }

    @Get()
    // @UseGuards(AuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    // @UseGuards(AuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AuthGuard)
    update(
      @Param("id") id: string,
      @Body() dto: UpdateShippingAddressDto,
      @Req() request: any
    ) {
        return this.service.update(id, dto, request);
    }

    @Delete(":id")
    // @UseGuards(AuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
