import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { RetailerImageGalleryRepository } from './retailer-image-gallery.repository';
import { CreateRetailerImageGalleryDto } from './dto/create-retailer-image-gallery.dto';
import { UpdateRetailerImageGalleryDto } from './dto/update-retailer-image-gallery.dto';
import { RetailerImageGalleryEntity } from './entities/retailer-image-gallery.entity';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class RetailerImageGalleryService {
    constructor(
        @InjectRepository(RetailerImageGalleryRepository)
        private readonly repository: RetailerImageGalleryRepository,
        private readonly doSpaceService: DoSpacesService
    ) { }

    async create(
        dto: CreateRetailerImageGalleryDto,
        files: {
            image: UploadedMulterFileI,
        }): Promise<RetailerImageGalleryEntity | Error> {
        // process image one
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], 'RetailerImageGalleryEntity/');
            dto.image = image;
        }

        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product image gallery created successfully", "data", data);
    }

    async findAll(): Promise<RetailerImageGalleryEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product image gallery fetched successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateRetailerImageGalleryDto,
        files: {
            image: UploadedMulterFileI,
        }
    ): Promise<RetailerImageGalleryEntity | Error> {
        const RetailerImageGalleryEntity: any = await this.repository.findOneEntity(id);
        if (!RetailerImageGalleryEntity) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }

        // process image one
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], 'RetailerImageGalleryEntity/');
            dto.image = image;
        }

        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product image gallery updated successfully", "data", data);
    }

    async findOne(id: string): Promise<RetailerImageGalleryEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product image gallery fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product image gallery deleted successfully");
    }
}
