import { Module } from "@nestjs/common";
import { SchedulerService } from "./scheduler.service";
import { SchedulerController } from "./scheduler.controller";
import { ScheduleModule } from "@nestjs/schedule";
import { TypeOrmModule } from "@nestjs/typeorm";
import { UsersRepository } from "../users/user.repository";
import {
    ProductCategoryRepository
} from "../dutchie-plus/custom-services/product-category/product-category.repository";
import { ProductServiceRepository } from "../dutchie-plus/custom-services/product-service/product-service.repository";
import {
    RetailerServiceRepository
} from "../dutchie-plus/custom-services/retailer-service/retailer-service.repository";
import { ElasticsearchModule } from "@nestjs/elasticsearch";
import { ProductEffectsRepository } from "../dutchie-plus/custom-services/product-effects/product-effects.repository";

@Module({
    imports: [
        ScheduleModule.forRoot(),
        TypeOrmModule.forFeature([
            UsersRepository,
            ProductCategoryRepository,
            ProductServiceRepository,
            RetailerServiceRepository,
            ProductEffectsRepository
        ]),
        ElasticsearchModule.registerAsync({
            useFactory: async () => ({
                node: process.env.ELASTIC_NODE,
                auth: {
                    apiKey: process.env.ELASTIC_API_KEY
                },
                maxRetries: 10,
                requestTimeout: 60000
            })
        })
    ],
    controllers: [SchedulerController],
    providers: [SchedulerService]
})
export class SchedulerModule {
}
