import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateWeeklyAdTagsListDto } from "./dto/create-weekly-ad-tags-list.dto";
import { UpdateWeeklyAdTagsListDto } from "./dto/update-weekly-ad-tags-list.dto";
import { WeeklyAdTagsList } from "./entities/weekly-ad-tags-list.entity";

@EntityRepository(WeeklyAdTagsList)
export class WeeklyAdTagsListRepository extends Repository<WeeklyAdTagsList> {
    async createEntity(dto: CreateWeeklyAdTagsListDto): Promise<WeeklyAdTagsList | Error> {
        try {
            const {
                weeklyAdId,
                tagName,
                tagId
            } = dto;
            const entity = this.create({
                weeklyAdId,
                tagName,
                tagId
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<WeeklyAdTagsList | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findOneFilterEntity(query: any): Promise<WeeklyAdTagsList | Error> {
        try {
            return await this.findOne({ ...query, isDeleted: false });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateWeeklyAdTagsListDto): Promise<WeeklyAdTagsList | Error> {
        try {
            await this.update(id, {
                weeklyAdId: dto.weeklyAdId,
                tagName: dto.tagName,
                tagId: dto.tagId
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<WeeklyAdTagsList[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteWeeklyAdTagsList(id: any): Promise<any | Error> {
        try {
            const deleteResult = await getConnection()
                .createQueryBuilder()
                .delete()
                .from(WeeklyAdTagsList)
                .where("weeklyAdId = :weeklyAdId", { weeklyAdId: id })
                .execute();
            if (deleteResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }

    }


    async bulkInsertWeeklyAdTagsList(list: any): Promise<any | Error> {
        try {
            const insertResult = await getConnection()
                .createQueryBuilder()
                .insert()
                .into(WeeklyAdTagsList)
                .values(list)
                .execute();
            if (insertResult.raw.affected > 0) {
                return true;
            }
            return false;
        }

        catch (e) {
            return e;
        }

    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(WeeklyAdTagsList)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}